Class: DdrClient::DdrAPIBatchEntity
- Inherits:
-
Object
- Object
- DdrClient::DdrAPIBatchEntity
- Defined in:
- lib/ddr_client/models/ddr_api_batch_entity.rb
Overview
Ddr_API_BatchEntity model
Instance Attribute Summary collapse
-
#batch_objects ⇒ Object
Returns the value of attribute batch_objects.
-
#collection_id ⇒ Object
Returns the value of attribute collection_id.
-
#collection_title ⇒ Object
Returns the value of attribute collection_title.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#description ⇒ Object
Returns the value of attribute description.
-
#id ⇒ Object
Returns the value of attribute id.
-
#links ⇒ Object
Returns the value of attribute links.
-
#logfile ⇒ Object
Returns the value of attribute logfile.
-
#name ⇒ Object
Returns the value of attribute name.
-
#outcome ⇒ Object
Returns the value of attribute outcome.
-
#processing_started_at ⇒ Object
Returns the value of attribute processing_started_at.
-
#started_at ⇒ Object
Returns the value of attribute started_at.
-
#status ⇒ Object
Returns the value of attribute status.
-
#stopped_at ⇒ Object
Returns the value of attribute stopped_at.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
-
#user ⇒ Object
Returns the value of attribute user.
-
#version ⇒ Object
Returns the value of attribute version.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DdrAPIBatchEntity
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ DdrAPIBatchEntity
Initializes the object
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/ddr_client/models/ddr_api_batch_entity.rb', line 100 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'collection_id') self.collection_id = attributes[:'collection_id'] end if attributes.has_key?(:'collection_title') self.collection_title = attributes[:'collection_title'] end if attributes.has_key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.has_key?(:'description') self.description = attributes[:'description'] end if attributes.has_key?(:'id') self.id = attributes[:'id'] end if attributes.has_key?(:'name') self.name = attributes[:'name'] end if attributes.has_key?(:'outcome') self.outcome = attributes[:'outcome'] end if attributes.has_key?(:'status') self.status = attributes[:'status'] end if attributes.has_key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end if attributes.has_key?(:'version') self.version = attributes[:'version'] end if attributes.has_key?(:'started_at') self.started_at = attributes[:'started_at'] end if attributes.has_key?(:'stopped_at') self.stopped_at = attributes[:'stopped_at'] end if attributes.has_key?(:'processing_started_at') self.processing_started_at = attributes[:'processing_started_at'] end if attributes.has_key?(:'logfile') self.logfile = attributes[:'logfile'] end if attributes.has_key?(:'user') self.user = attributes[:'user'] end if attributes.has_key?(:'batch_objects') if (value = attributes[:'batch_objects']).is_a?(Array) self.batch_objects = value end end if attributes.has_key?(:'links') if (value = attributes[:'links']).is_a?(Array) self.links = value end end end |
Instance Attribute Details
#batch_objects ⇒ Object
Returns the value of attribute batch_objects.
48 49 50 |
# File 'lib/ddr_client/models/ddr_api_batch_entity.rb', line 48 def batch_objects @batch_objects end |
#collection_id ⇒ Object
Returns the value of attribute collection_id.
18 19 20 |
# File 'lib/ddr_client/models/ddr_api_batch_entity.rb', line 18 def collection_id @collection_id end |
#collection_title ⇒ Object
Returns the value of attribute collection_title.
20 21 22 |
# File 'lib/ddr_client/models/ddr_api_batch_entity.rb', line 20 def collection_title @collection_title end |
#created_at ⇒ Object
Returns the value of attribute created_at.
22 23 24 |
# File 'lib/ddr_client/models/ddr_api_batch_entity.rb', line 22 def created_at @created_at end |
#description ⇒ Object
Returns the value of attribute description.
24 25 26 |
# File 'lib/ddr_client/models/ddr_api_batch_entity.rb', line 24 def description @description end |
#id ⇒ Object
Returns the value of attribute id.
26 27 28 |
# File 'lib/ddr_client/models/ddr_api_batch_entity.rb', line 26 def id @id end |
#links ⇒ Object
Returns the value of attribute links.
50 51 52 |
# File 'lib/ddr_client/models/ddr_api_batch_entity.rb', line 50 def links @links end |
#logfile ⇒ Object
Returns the value of attribute logfile.
44 45 46 |
# File 'lib/ddr_client/models/ddr_api_batch_entity.rb', line 44 def logfile @logfile end |
#name ⇒ Object
Returns the value of attribute name.
28 29 30 |
# File 'lib/ddr_client/models/ddr_api_batch_entity.rb', line 28 def name @name end |
#outcome ⇒ Object
Returns the value of attribute outcome.
30 31 32 |
# File 'lib/ddr_client/models/ddr_api_batch_entity.rb', line 30 def outcome @outcome end |
#processing_started_at ⇒ Object
Returns the value of attribute processing_started_at.
42 43 44 |
# File 'lib/ddr_client/models/ddr_api_batch_entity.rb', line 42 def processing_started_at @processing_started_at end |
#started_at ⇒ Object
Returns the value of attribute started_at.
38 39 40 |
# File 'lib/ddr_client/models/ddr_api_batch_entity.rb', line 38 def started_at @started_at end |
#status ⇒ Object
Returns the value of attribute status.
32 33 34 |
# File 'lib/ddr_client/models/ddr_api_batch_entity.rb', line 32 def status @status end |
#stopped_at ⇒ Object
Returns the value of attribute stopped_at.
40 41 42 |
# File 'lib/ddr_client/models/ddr_api_batch_entity.rb', line 40 def stopped_at @stopped_at end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
34 35 36 |
# File 'lib/ddr_client/models/ddr_api_batch_entity.rb', line 34 def updated_at @updated_at end |
#user ⇒ Object
Returns the value of attribute user.
46 47 48 |
# File 'lib/ddr_client/models/ddr_api_batch_entity.rb', line 46 def user @user end |
#version ⇒ Object
Returns the value of attribute version.
36 37 38 |
# File 'lib/ddr_client/models/ddr_api_batch_entity.rb', line 36 def version @version end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/ddr_client/models/ddr_api_batch_entity.rb', line 53 def self.attribute_map { :'collection_id' => :'collection_id', :'collection_title' => :'collection_title', :'created_at' => :'created_at', :'description' => :'description', :'id' => :'id', :'name' => :'name', :'outcome' => :'outcome', :'status' => :'status', :'updated_at' => :'updated_at', :'version' => :'version', :'started_at' => :'started_at', :'stopped_at' => :'stopped_at', :'processing_started_at' => :'processing_started_at', :'logfile' => :'logfile', :'user' => :'user', :'batch_objects' => :'batch_objects', :'links' => :'links' } end |
.swagger_types ⇒ Object
Attribute type mapping.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/ddr_client/models/ddr_api_batch_entity.rb', line 76 def self.swagger_types { :'collection_id' => :'String', :'collection_title' => :'String', :'created_at' => :'String', :'description' => :'String', :'id' => :'String', :'name' => :'String', :'outcome' => :'String', :'status' => :'String', :'updated_at' => :'String', :'version' => :'String', :'started_at' => :'String', :'stopped_at' => :'String', :'processing_started_at' => :'String', :'logfile' => :'DdrAPIBatchEntityLogfile', :'user' => :'DdrAPIUserEntity', :'batch_objects' => :'Array<DdrAPIBatchObjectEntity>', :'links' => :'Array<DdrAPILinkEntity>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 |
# File 'lib/ddr_client/models/ddr_api_batch_entity.rb', line 194 def ==(o) return true if self.equal?(o) self.class == o.class && collection_id == o.collection_id && collection_title == o.collection_title && created_at == o.created_at && description == o.description && id == o.id && name == o.name && outcome == o.outcome && status == o.status && updated_at == o.updated_at && version == o.version && started_at == o.started_at && stopped_at == o.stopped_at && processing_started_at == o.processing_started_at && logfile == o.logfile && user == o.user && batch_objects == o.batch_objects && links == o.links end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 |
# File 'lib/ddr_client/models/ddr_api_batch_entity.rb', line 252 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = DdrClient.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
318 319 320 321 322 323 324 325 326 327 328 329 330 |
# File 'lib/ddr_client/models/ddr_api_batch_entity.rb', line 318 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 |
# File 'lib/ddr_client/models/ddr_api_batch_entity.rb', line 231 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
218 219 220 |
# File 'lib/ddr_client/models/ddr_api_batch_entity.rb', line 218 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
224 225 226 |
# File 'lib/ddr_client/models/ddr_api_batch_entity.rb', line 224 def hash [collection_id, collection_title, created_at, description, id, name, outcome, status, updated_at, version, started_at, stopped_at, processing_started_at, logfile, user, batch_objects, links].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
181 182 183 184 |
# File 'lib/ddr_client/models/ddr_api_batch_entity.rb', line 181 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
298 299 300 |
# File 'lib/ddr_client/models/ddr_api_batch_entity.rb', line 298 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
304 305 306 307 308 309 310 311 312 |
# File 'lib/ddr_client/models/ddr_api_batch_entity.rb', line 304 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
292 293 294 |
# File 'lib/ddr_client/models/ddr_api_batch_entity.rb', line 292 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
188 189 190 |
# File 'lib/ddr_client/models/ddr_api_batch_entity.rb', line 188 def valid? true end |