Class: DdrClient::DdrAPIEventEntity
- Inherits:
-
Object
- Object
- DdrClient::DdrAPIEventEntity
- Defined in:
- lib/ddr_client/models/ddr_api_event_entity.rb
Overview
Ddr_API_EventEntity model
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#description ⇒ Object
Operator comment or automated summary of event action.
-
#detail ⇒ Object
Additional description of or information from the event, such as an exception.
-
#event_date_time ⇒ Object
When the event occurred or was recorded.
-
#id ⇒ Object
Event ID.
-
#links ⇒ Object
Returns the value of attribute links.
-
#operator ⇒ Object
Person or entity responsible for initiating or causing the event.
-
#outcome ⇒ Object
Event outcome cast as a success or failure.
-
#resource_id ⇒ Object
ID of the resource to which the event pertains.
-
#software ⇒ Object
Software associated with the event.
-
#type ⇒ Object
Event category.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DdrAPIEventEntity
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ DdrAPIEventEntity
Initializes the object
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/ddr_client/models/ddr_api_event_entity.rb', line 103 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'id') self.id = attributes[:'id'] end if attributes.has_key?(:'resource_id') self.resource_id = attributes[:'resource_id'] end if attributes.has_key?(:'type') self.type = attributes[:'type'] end if attributes.has_key?(:'description') self.description = attributes[:'description'] end if attributes.has_key?(:'event_date_time') self.event_date_time = attributes[:'event_date_time'] end if attributes.has_key?(:'outcome') self.outcome = attributes[:'outcome'] end if attributes.has_key?(:'software') self.software = attributes[:'software'] else self.software = 'ddr-admin 2.0.0+de733cf0' end if attributes.has_key?(:'detail') self.detail = attributes[:'detail'] end if attributes.has_key?(:'operator') self.operator = attributes[:'operator'] else self.operator = 'SYSTEM' end if attributes.has_key?(:'links') self.links = attributes[:'links'] end end |
Instance Attribute Details
#description ⇒ Object
Operator comment or automated summary of event action
28 29 30 |
# File 'lib/ddr_client/models/ddr_api_event_entity.rb', line 28 def description @description end |
#detail ⇒ Object
Additional description of or information from the event, such as an exception
40 41 42 |
# File 'lib/ddr_client/models/ddr_api_event_entity.rb', line 40 def detail @detail end |
#event_date_time ⇒ Object
When the event occurred or was recorded
31 32 33 |
# File 'lib/ddr_client/models/ddr_api_event_entity.rb', line 31 def event_date_time @event_date_time end |
#id ⇒ Object
Event ID
19 20 21 |
# File 'lib/ddr_client/models/ddr_api_event_entity.rb', line 19 def id @id end |
#links ⇒ Object
Returns the value of attribute links.
45 46 47 |
# File 'lib/ddr_client/models/ddr_api_event_entity.rb', line 45 def links @links end |
#operator ⇒ Object
Person or entity responsible for initiating or causing the event
43 44 45 |
# File 'lib/ddr_client/models/ddr_api_event_entity.rb', line 43 def operator @operator end |
#outcome ⇒ Object
Event outcome cast as a success or failure
34 35 36 |
# File 'lib/ddr_client/models/ddr_api_event_entity.rb', line 34 def outcome @outcome end |
#resource_id ⇒ Object
ID of the resource to which the event pertains
22 23 24 |
# File 'lib/ddr_client/models/ddr_api_event_entity.rb', line 22 def resource_id @resource_id end |
#software ⇒ Object
Software associated with the event
37 38 39 |
# File 'lib/ddr_client/models/ddr_api_event_entity.rb', line 37 def software @software end |
#type ⇒ Object
Event category
25 26 27 |
# File 'lib/ddr_client/models/ddr_api_event_entity.rb', line 25 def type @type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/ddr_client/models/ddr_api_event_entity.rb', line 70 def self.attribute_map { :'id' => :'id', :'resource_id' => :'resource_id', :'type' => :'type', :'description' => :'description', :'event_date_time' => :'event_date_time', :'outcome' => :'outcome', :'software' => :'software', :'detail' => :'detail', :'operator' => :'operator', :'links' => :'links' } end |
.swagger_types ⇒ Object
Attribute type mapping.
86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/ddr_client/models/ddr_api_event_entity.rb', line 86 def self.swagger_types { :'id' => :'Integer', :'resource_id' => :'String', :'type' => :'String', :'description' => :'String', :'event_date_time' => :'DateTime', :'outcome' => :'String', :'software' => :'String', :'detail' => :'String', :'operator' => :'String', :'links' => :'DdrAPILinkEntity' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
193 194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/ddr_client/models/ddr_api_event_entity.rb', line 193 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && resource_id == o.resource_id && type == o.type && description == o.description && event_date_time == o.event_date_time && outcome == o.outcome && software == o.software && detail == o.detail && operator == o.operator && links == o.links end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 |
# File 'lib/ddr_client/models/ddr_api_event_entity.rb', line 244 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = DdrClient.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
310 311 312 313 314 315 316 317 318 319 320 321 322 |
# File 'lib/ddr_client/models/ddr_api_event_entity.rb', line 310 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/ddr_client/models/ddr_api_event_entity.rb', line 223 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
210 211 212 |
# File 'lib/ddr_client/models/ddr_api_event_entity.rb', line 210 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
216 217 218 |
# File 'lib/ddr_client/models/ddr_api_event_entity.rb', line 216 def hash [id, resource_id, type, description, event_date_time, outcome, software, detail, operator, links].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
156 157 158 159 |
# File 'lib/ddr_client/models/ddr_api_event_entity.rb', line 156 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
290 291 292 |
# File 'lib/ddr_client/models/ddr_api_event_entity.rb', line 290 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
296 297 298 299 300 301 302 303 304 |
# File 'lib/ddr_client/models/ddr_api_event_entity.rb', line 296 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
284 285 286 |
# File 'lib/ddr_client/models/ddr_api_event_entity.rb', line 284 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
163 164 165 166 167 168 169 |
# File 'lib/ddr_client/models/ddr_api_event_entity.rb', line 163 def valid? type_validator = EnumAttributeValidator.new('String', ['Creation', 'Deaccession', 'Deletion', 'FixityCheck', 'Ingestion', 'Migration', 'Update', 'Validation', 'VirusCheck']) return false unless type_validator.valid?(@type) outcome_validator = EnumAttributeValidator.new('String', ['success', 'failure']) return false unless outcome_validator.valid?(@outcome) true end |