Class: DdrClient::DdrAPIBatchObjectEntity
- Inherits:
-
Object
- Object
- DdrClient::DdrAPIBatchObjectEntity
- Defined in:
- lib/ddr_client/models/ddr_api_batch_object_entity.rb
Overview
Ddr_API_BatchObjectEntity model
Instance Attribute Summary collapse
-
#attributes ⇒ Object
Returns the value of attribute attributes.
-
#batch_id ⇒ Object
Returns the value of attribute batch_id.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#files ⇒ Object
Returns the value of attribute files.
-
#handled ⇒ Object
Returns the value of attribute handled.
-
#id ⇒ Object
Returns the value of attribute id.
-
#identifier ⇒ Object
Returns the value of attribute identifier.
-
#label ⇒ Object
Returns the value of attribute label.
-
#links ⇒ Object
Returns the value of attribute links.
-
#messages ⇒ Object
Returns the value of attribute messages.
-
#model ⇒ Object
Returns the value of attribute model.
-
#processed ⇒ Object
Returns the value of attribute processed.
-
#relationships ⇒ Object
Returns the value of attribute relationships.
-
#resource_id ⇒ Object
Returns the value of attribute resource_id.
-
#roles ⇒ Object
Returns the value of attribute roles.
-
#type ⇒ Object
Returns the value of attribute type.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
-
#validated ⇒ Object
Returns the value of attribute validated.
-
#verified ⇒ Object
Returns the value of attribute verified.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DdrAPIBatchObjectEntity
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ DdrAPIBatchObjectEntity
Initializes the object
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/ddr_client/models/ddr_api_batch_object_entity.rb', line 108 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'id') self.id = attributes[:'id'] end if attributes.has_key?(:'batch_id') self.batch_id = attributes[:'batch_id'] end if attributes.has_key?(:'identifier') self.identifier = attributes[:'identifier'] end if attributes.has_key?(:'model') self.model = attributes[:'model'] end if attributes.has_key?(:'label') self.label = attributes[:'label'] end if attributes.has_key?(:'resource_id') self.resource_id = attributes[:'resource_id'] end if attributes.has_key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.has_key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end if attributes.has_key?(:'type') self.type = attributes[:'type'] end if attributes.has_key?(:'verified') self.verified = attributes[:'verified'] end if attributes.has_key?(:'handled') self.handled = attributes[:'handled'] end if attributes.has_key?(:'processed') self.processed = attributes[:'processed'] end if attributes.has_key?(:'validated') self.validated = attributes[:'validated'] end if attributes.has_key?(:'attributes') self.attributes = attributes[:'attributes'] end if attributes.has_key?(:'files') self.files = attributes[:'files'] end if attributes.has_key?(:'messages') self. = attributes[:'messages'] end if attributes.has_key?(:'relationships') self.relationships = attributes[:'relationships'] end if attributes.has_key?(:'roles') self.roles = attributes[:'roles'] end if attributes.has_key?(:'links') if (value = attributes[:'links']).is_a?(Array) self.links = value end end end |
Instance Attribute Details
#attributes ⇒ Object
Returns the value of attribute attributes.
44 45 46 |
# File 'lib/ddr_client/models/ddr_api_batch_object_entity.rb', line 44 def attributes @attributes end |
#batch_id ⇒ Object
Returns the value of attribute batch_id.
20 21 22 |
# File 'lib/ddr_client/models/ddr_api_batch_object_entity.rb', line 20 def batch_id @batch_id end |
#created_at ⇒ Object
Returns the value of attribute created_at.
30 31 32 |
# File 'lib/ddr_client/models/ddr_api_batch_object_entity.rb', line 30 def created_at @created_at end |
#files ⇒ Object
Returns the value of attribute files.
46 47 48 |
# File 'lib/ddr_client/models/ddr_api_batch_object_entity.rb', line 46 def files @files end |
#handled ⇒ Object
Returns the value of attribute handled.
38 39 40 |
# File 'lib/ddr_client/models/ddr_api_batch_object_entity.rb', line 38 def handled @handled end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/ddr_client/models/ddr_api_batch_object_entity.rb', line 18 def id @id end |
#identifier ⇒ Object
Returns the value of attribute identifier.
22 23 24 |
# File 'lib/ddr_client/models/ddr_api_batch_object_entity.rb', line 22 def identifier @identifier end |
#label ⇒ Object
Returns the value of attribute label.
26 27 28 |
# File 'lib/ddr_client/models/ddr_api_batch_object_entity.rb', line 26 def label @label end |
#links ⇒ Object
Returns the value of attribute links.
54 55 56 |
# File 'lib/ddr_client/models/ddr_api_batch_object_entity.rb', line 54 def links @links end |
#messages ⇒ Object
Returns the value of attribute messages.
48 49 50 |
# File 'lib/ddr_client/models/ddr_api_batch_object_entity.rb', line 48 def @messages end |
#model ⇒ Object
Returns the value of attribute model.
24 25 26 |
# File 'lib/ddr_client/models/ddr_api_batch_object_entity.rb', line 24 def model @model end |
#processed ⇒ Object
Returns the value of attribute processed.
40 41 42 |
# File 'lib/ddr_client/models/ddr_api_batch_object_entity.rb', line 40 def processed @processed end |
#relationships ⇒ Object
Returns the value of attribute relationships.
50 51 52 |
# File 'lib/ddr_client/models/ddr_api_batch_object_entity.rb', line 50 def relationships @relationships end |
#resource_id ⇒ Object
Returns the value of attribute resource_id.
28 29 30 |
# File 'lib/ddr_client/models/ddr_api_batch_object_entity.rb', line 28 def resource_id @resource_id end |
#roles ⇒ Object
Returns the value of attribute roles.
52 53 54 |
# File 'lib/ddr_client/models/ddr_api_batch_object_entity.rb', line 52 def roles @roles end |
#type ⇒ Object
Returns the value of attribute type.
34 35 36 |
# File 'lib/ddr_client/models/ddr_api_batch_object_entity.rb', line 34 def type @type end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
32 33 34 |
# File 'lib/ddr_client/models/ddr_api_batch_object_entity.rb', line 32 def updated_at @updated_at end |
#validated ⇒ Object
Returns the value of attribute validated.
42 43 44 |
# File 'lib/ddr_client/models/ddr_api_batch_object_entity.rb', line 42 def validated @validated end |
#verified ⇒ Object
Returns the value of attribute verified.
36 37 38 |
# File 'lib/ddr_client/models/ddr_api_batch_object_entity.rb', line 36 def verified @verified end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/ddr_client/models/ddr_api_batch_object_entity.rb', line 57 def self.attribute_map { :'id' => :'id', :'batch_id' => :'batch_id', :'identifier' => :'identifier', :'model' => :'model', :'label' => :'label', :'resource_id' => :'resource_id', :'created_at' => :'created_at', :'updated_at' => :'updated_at', :'type' => :'type', :'verified' => :'verified', :'handled' => :'handled', :'processed' => :'processed', :'validated' => :'validated', :'attributes' => :'attributes', :'files' => :'files', :'messages' => :'messages', :'relationships' => :'relationships', :'roles' => :'roles', :'links' => :'links' } end |
.swagger_types ⇒ Object
Attribute type mapping.
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/ddr_client/models/ddr_api_batch_object_entity.rb', line 82 def self.swagger_types { :'id' => :'String', :'batch_id' => :'String', :'identifier' => :'String', :'model' => :'String', :'label' => :'String', :'resource_id' => :'String', :'created_at' => :'String', :'updated_at' => :'String', :'type' => :'String', :'verified' => :'String', :'handled' => :'String', :'processed' => :'String', :'validated' => :'String', :'attributes' => :'DdrAPIBatchObjectAttributeEntity', :'files' => :'DdrAPIBatchObjectDatastreamEntity', :'messages' => :'DdrAPIBatchObjectMessageEntity', :'relationships' => :'DdrAPIBatchObjectRelationshipEntity', :'roles' => :'DdrAPIBatchObjectRoleEntity', :'links' => :'Array<DdrAPILinkEntity>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 |
# File 'lib/ddr_client/models/ddr_api_batch_object_entity.rb', line 208 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && batch_id == o.batch_id && identifier == o.identifier && model == o.model && label == o.label && resource_id == o.resource_id && created_at == o.created_at && updated_at == o.updated_at && type == o.type && verified == o.verified && handled == o.handled && processed == o.processed && validated == o.validated && attributes == o.attributes && files == o.files && == o. && relationships == o.relationships && roles == o.roles && links == o.links end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 |
# File 'lib/ddr_client/models/ddr_api_batch_object_entity.rb', line 268 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = DdrClient.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
334 335 336 337 338 339 340 341 342 343 344 345 346 |
# File 'lib/ddr_client/models/ddr_api_batch_object_entity.rb', line 334 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 |
# File 'lib/ddr_client/models/ddr_api_batch_object_entity.rb', line 247 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
234 235 236 |
# File 'lib/ddr_client/models/ddr_api_batch_object_entity.rb', line 234 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
240 241 242 |
# File 'lib/ddr_client/models/ddr_api_batch_object_entity.rb', line 240 def hash [id, batch_id, identifier, model, label, resource_id, created_at, updated_at, type, verified, handled, processed, validated, attributes, files, , relationships, roles, links].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
195 196 197 198 |
# File 'lib/ddr_client/models/ddr_api_batch_object_entity.rb', line 195 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
314 315 316 |
# File 'lib/ddr_client/models/ddr_api_batch_object_entity.rb', line 314 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
320 321 322 323 324 325 326 327 328 |
# File 'lib/ddr_client/models/ddr_api_batch_object_entity.rb', line 320 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
308 309 310 |
# File 'lib/ddr_client/models/ddr_api_batch_object_entity.rb', line 308 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
202 203 204 |
# File 'lib/ddr_client/models/ddr_api_batch_object_entity.rb', line 202 def valid? true end |